config() {
  NEW="$1"
  OLD="$(dirname $NEW)/$(basename $NEW .new)"
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "$(cat $OLD | md5sum)" = "$(cat $NEW | md5sum)" ]; then
    rm $NEW
  fi
}

config etc/gdm/custom.conf.new

# Set the wayland-session script and gdm wrapper executable:
( cd etc/gdm ; chmod 0755 wayland-session )
( cd usr/sbin ; chmod 0755 gdm )

if [ -e usr/share/glib-2.0/schemas ]; then
  if [ -x /usr/bin/glib-compile-schemas ]; then
    /usr/bin/glib-compile-schemas usr/share/glib-2.0/schemas >/dev/null 2>&1
  fi
fi
( cd usr/lib64 ; rm -rf libgdm.so )
( cd usr/lib64 ; ln -sf libgdm.so.1 libgdm.so )
( cd usr/lib64 ; rm -rf libgdm.so.1 )
( cd usr/lib64 ; ln -sf libgdm.so.1.0.0 libgdm.so.1 )
